@@ -1,98 +1,12 @@
 import os
 import sys
 import yaml
+import pickle
 
-notifier = None
-try:
-    from gntp import notifier
-    import socket
-except ImportError:
-    pass
-
-from fnmatch import fnmatch
 from strange_case.registry import Registry
-from strange_case.processors import build_node
 from strange_case.nodes import Node
 from strange_case.config_dict import ConfigDict
-
-
-def scan(folder):
-    ret = []
-    for f in os.listdir(folder):
-        if f.startswith('.'):
-            continue
-
-        f = os.path.join(folder, f)
-        ret.append(f)
-        if os.path.isdir(f):
-            ret.extend(scan(f))
-    return ret
-
-
-def strange_case(config):
-    # pull out important values.
-    site_path = config['site_path']
-    deploy_path = config['deploy_path']
-
-    # look for files in content/
-    if not os.path.isdir(site_path):
-        raise IOError('Could not find site_path folder "%s"' % site_path)
-
-    # this is the one folder that *doesn't* get processed by processors.build_page_tree,
-    # so it needs special handling here.
-    config.setdefault('type', 'root')
-    Node.files_written = []
-    root_node = build_node(config, site_path, deploy_path, '')[0]
-
-    remove_stale_files = config['remove_stale_files']
-    dont_remove = config['dont_remove']
-    existing_files = []
-    if os.path.isdir(deploy_path):
-        existing_files = scan(deploy_path)
-    else:
-        os.makedirs(deploy_path, 0755)
-    root_node.generate()
-    if remove_stale_files and existing_files:
-        paths = []
-        for f in existing_files:
-            if f not in Node.files_written:
-                f = os.path.abspath(f)
-                f_rel = os.path.relpath(f)
-                if any(pattern for pattern in dont_remove if fnmatch(f, pattern)):
-                    sys.stderr.write("\033[32mignoring\033[0m \033[1m" + f_rel + "\033[0m\n")
-                    continue
-
-                if os.path.isdir(f):
-                    paths.insert(0, f)
-                else:
-                    sys.stderr.write("\033[31mrm\033[0m \033[1m" + f_rel + "\033[0m\n")
-                    os.remove(f)
-        # filter out directories that are not empty
-        paths = [p for p in paths if not os.listdir(p)]
-        for p in paths:
-            p_rel = os.path.relpath(p)
-            sys.stderr.write("\033[31mrmdir\033[0m \033[1m" + p_rel + "\033[0m\n")
-            os.removedirs(p)
-
-    if notifier:
-        try:
-            growl = notifier.GrowlNotifier(
-                applicationName="StrangeCase",
-                notifications=["New Messages"],
-                defaultNotifications=["New Messages"],
-            )
-            growl.register()
-
-            # Send one message
-            growl.notify(
-                noteType="New Messages",
-                title="StrangeCase site generated",
-                description="site is available at:\n"
-                    "{config[deploy_path]}"\
-                    .format(config=config),
-            )
-        except socket.error:
-            pass
+from strange_case import strange_case
 
 
 def fancy_import(import_name):
@@ -199,7 +113,7 @@ def run():
                 try:
                     extension = fancy_import(extension)
                 except ImportError:
-                    print 'Error in processors: Could not find "%s"' % extension
+                    sys.error.write('Error in processors: Could not find "%s"\n' % extension)
                     raise
             extensions.append(extension)
         del CONFIG['extensions']
@@ -216,7 +130,7 @@ def run():
                 try:
                     method = fancy_import(method)
                 except ImportError:
-                    print 'Error in filters: Could not find "%s"' % method
+                    sys.error.write('Error in filters: Could not find "%s"\n' % method)
                     raise
             jinja_environment.filters[filter_name] = method
         del CONFIG['filters']
@@ -226,7 +140,7 @@ def run():
             try:
                 fancy_import(processor)
             except ImportError:
-                print 'Error in processors: Could not find "%s"' % processor
+                sys.error.write('Error in processors: Could not find "%s"\n' % processor)
                 raise
         del CONFIG['processors']
 
@@ -246,7 +160,7 @@ def run():
                 configurator = fancy_import(configurator)
             configurators.append(configurator)
             Registry.add_configurator(configurator)
-        del CONFIG['configurators']
+        del CONFIG['configurators +']
 
     # additional file_types
     for entry in Registry.file_types:
@@ -255,6 +169,16 @@ def run():
     if 'file_types +' in CONFIG:
         CONFIG['file_types'].extend(CONFIG['file_types +'])
 
+    # read timestamps file
+    timestamps_file = os.path.join(CONFIG['project_path'], '.timestamps')
+    if os.path.exists(timestamps_file):
+        CONFIG['file_mtimes'] = pickle.load(open(timestamps_file))
+
+    timestamps = {}
+    for file_tracked in Node.files_tracked:
+        f = os.path.abspath(file_tracked)
+        timestamps[f] = os.stat(file_tracked).st_mtime
+
     if args.watch:
         import time
         from watchdog.observers import Observer
